package de.thdeg.greiner.superpangworld.graphics.base;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.moveable.Player;

import java.util.ArrayList;

/**
 * A Bubble, which moves around on the screen and can be shot by the player.
 */
public abstract class Bubble extends CollidingGameObject implements MovingGameObject{

    /** Flag, if the bubble flies from left to right */
    private boolean flyFromLeftToRight;

    /**
     * Create a bubble with default values.
     *
     * @param gameView the {@link GameView} to display the bubble
     * @param objectsToCollideWith the list of {@link CollidableGameObject} the bubble can collide with
     */
    public Bubble(GameView gameView, ArrayList<CollidableGameObject> objectsToCollideWith){
        super(gameView,objectsToCollideWith);
        rotation = 90;
        size = 5;
        width = (int) (12 * size);
        height = (int) (12 * size);
        speedInPixel = 5;
        flyFromLeftToRight = true;
    }

    /**
     * Moves the bubble a tick further.
     */
    @Override
    public void updatePosition(){
        if(flyFromLeftToRight && getPosition().x + (width*size) >= GameView.WIDTH){
            flyFromLeftToRight = false;
        }else if (!flyFromLeftToRight && getPosition().x <= 0){
            flyFromLeftToRight = true;
        }
        if(flyFromLeftToRight){
            getPosition().right(1);
        }else{
            getPosition().left(1);
        }
    }

    /**
     * Pop the bubble.
     */
    private void popBubble(){}

    /**
     * Freezes the time.
     */
    private void freezeTime(){}

    @Override
    public void reactToCollision(CollidableGameObject otherObject) {
        if(otherObject instanceof Player){
            System.out.println("You died!");
        }
    }
}
