package de.thdeg.greiner.superpangworld.graphics.moveable;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.base.*;

import java.awt.*;
import java.util.ArrayList;

/**
 * A harpoon which can be fired upwards by the player.
 */
public class Harpoon extends CollidingGameObject implements MovingGameObject {

    private final static String HARPOON =
                    "   B   \n"+
                    "  BBB  \n"+
                    " kkkkk \n"+
                    "k kkk k\n"+
                    "k kkk k\n";

    /**
     * Create a harpoon with default values
     *
     * @param gameView the {@link GameView} to display the bubble
     * @param objectsToCollideWith the list of {@link CollidableGameObject} the harpoon can collide with
     */
    public Harpoon(GameView gameView, ArrayList<CollidableGameObject> objectsToCollideWith){
        super(gameView, objectsToCollideWith);
        speedInPixel = 1;
        size = 3;
        width = (int) (7 * size);
        height = (int) (5 * size);
        rotation = 0;
        getPosition().setTo(300,300);
        this.hitBox.width = (int) (width);
        this.hitBox.height = (int) (height);
    }

    @Override
    protected void updateHitBoxPosition() {
        hitBox.x = (int) (position.x);
        hitBox.y = (int) (position.y);
    }

    @Override
    public void reactToCollision(CollidableGameObject otherObject) {
        gamePlayManager.destroy(this);
        if(Bubble.class.isAssignableFrom(otherObject.getClass())){
            gamePlayManager.destroy((Bubble)otherObject);
        }
    }

    /**
     * Draws the harpoon onto the  {@link GameView}.
     */
    @Override
    public void addToCanvas(){
        gameView.addBlockImageToCanvas(HARPOON, getPosition().x, getPosition().y,size, rotation);
        gameView.addRectangleToCanvas(hitBox.x, hitBox.y, hitBox.width, hitBox.height,1,false, Color.red);
    }

    /**
     * Moves the harpoon a tick further upwards.
     */
    @Override
    public void updatePosition(){
        getPosition().up(speedInPixel);
    }

    /**
     * Deletes the harpoon if it hits the roof.
     */
    @Override
    public void updateStatus() {
        if(position.y <=0 ){
            gamePlayManager.destroy(this);
        }
    }
}
